==> haskell-text-conversions-0.3.1.1-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-conversions
version:              0.3.1.1
visibility:           public
id:                   text-conversions-0.3.1.1-2paG2PEYuZv68CVJfwKtmA
key:                  text-conversions-0.3.1.1-2paG2PEYuZv68CVJfwKtmA
license:              ISC
maintainer:           Alexis King <lexi.lambda@gmail.com>
author:               Alexis King
homepage:             https://github.com/cjdev/text-conversions
synopsis:             Safe conversions between textual types
description:          Safe conversions between textual types
category:             Data
abi:                  8ba48cc8374f7329ecd530b48463eace
exposed:              True
exposed-modules:      Data.Text.Conversions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-conversions-0.3.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-conversions-0.3.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-conversions-0.3.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-conversions
hs-libraries:         HStext-conversions-0.3.1.1-2paG2PEYuZv68CVJfwKtmA
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-L60Rqi32njv1QNA4jOe3ZV
    base64-bytestring-1.2.1.0-9p4vtkAuTQ4GHdtuHWxZHU
    bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-text-conversions/html/text-conversions.haddock

haddock-html:         /usr/share/doc/haskell-text-conversions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-conversions-0.3.1.1-100-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-conversions
version:              0.3.1.1
visibility:           public
id:                   text-conversions-0.3.1.1-DJ0QMsrnVNFF11zKhV2e4t
key:                  text-conversions-0.3.1.1-DJ0QMsrnVNFF11zKhV2e4t
license:              ISC
maintainer:           Alexis King <lexi.lambda@gmail.com>
author:               Alexis King
homepage:             https://github.com/cjdev/text-conversions
synopsis:             Safe conversions between textual types
description:          Safe conversions between textual types
category:             Data
abi:                  689a871e2d3b2e74ca7e28e489543153
exposed:              True
exposed-modules:      Data.Text.Conversions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-conversions-0.3.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-conversions-0.3.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-conversions-0.3.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-conversions
hs-libraries:         HStext-conversions-0.3.1.1-DJ0QMsrnVNFF11zKhV2e4t
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-8y3SyptL8obHk6RuDrxcpW
    base64-bytestring-1.2.1.0-8gOUUHpnCxrFKKvfql8iQu
    bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-text-conversions/html/text-conversions.haddock

haddock-html:         /usr/share/doc/haskell-text-conversions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
